@@ -20,7 +20,7 @@
 #ifndef PYOTHERSIDE_PYOBJECT_REF_H
 #define PYOTHERSIDE_PYOBJECT_REF_H
 
-#include "Python.h"
+#include "python_wrap.h"
 
 #include <QMetaType>
 
@@ -30,6 +30,7 @@ class PyObjectRef {
         PyObjectRef(const PyObjectRef &other);
         virtual ~PyObjectRef();
         PyObjectRef &operator=(const PyObjectRef &other);
+        bool operator==(const PyObjectRef &other);
 
         PyObject *newRef() const;
 
