@@ -1,7 +1,7 @@
 
 /**
  * PyOtherSide: Asynchronous Python 3 Bindings for Qt 5
- * Copyright (c) 2011, 2013-2019, Thomas Perl <m@thp.io>
+ * Copyright (c) 2011, 2013-2020, Thomas Perl <m@thp.io>
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -519,10 +519,11 @@ QPythonPriv::QPythonPriv()
 
     // Initialize sys.argv (https://github.com/thp/pyotherside/issues/77)
     int argc = 1;
-    wchar_t *argv[argc];
+    wchar_t **argv = (wchar_t **)malloc(argc * sizeof(wchar_t *));
     argv[0] = Py_DecodeLocale("", nullptr);
     PySys_SetArgvEx(argc, argv, 0);
     PyMem_RawFree((void *)argv[0]);
+    free(argv);
 
     locals = PyObjectRef(PyDict_New(), true);
     assert(locals);
